@@ -2,6 +2,18 @@ from ellipsis import apiManager
 from ellipsis import sanitize
 
 
+def add( name, token, parentId = None, publicAccess =None, metadata=None):
+    name = sanitize.validString('name', name, True)
+    token = sanitize.validString('token', token, True)
+    parentId = sanitize.validUuid('parentId', parentId, False)
+    metadata = sanitize.validObject('metadata', metadata, False)
+    publicAccess = sanitize.validObject('publicAccess', publicAccess, False)
+
+    body = {'name': name, 'parentId':parentId, 'publicAccess':publicAccess, 'metadata':metadata }
+
+    return apiManager.post('/path/raster', body, token)
+
+
 def editBand(pathId, bandNumber, name, token):
     token = sanitize.validString('token', token, True)
     pathId = sanitize.validUuid('pathId', pathId, True)
