@@ -3,6 +3,8 @@ from ellipsis import sanitize
 from ellipsis.util.root import recurse
 from ellipsis.util.root import stringToDate
 
+from ellipsis.path.folder.root import listFolder
+
 def searchRaster(root=None, name=None, fuzzySearchOnName=False, userId=None, disabled=False, canView=None, pageStart=None, hashtag=None, extent=None, bands=None, resolution=None, dateFrom=None, dateTo=None, hasTimestamp=None, timestampSize=None, listAll= False, token=None):
     token = sanitize.validString('token', token, False)
     root = sanitize.validStringArray('root', root, False)
@@ -125,6 +127,37 @@ def searchFolder(root=None, name=None, fuzzySearchOnName=False, userId=None, pag
     return r
 
 
+def searchFile(root=None, name=None, fuzzySearchOnName=False, userId=None, pageStart=None, listAll = False, token=None):
+    token = sanitize.validString('token', token, False)
+    listAll = sanitize.validBool('listAll', listAll, True)
+    root = sanitize.validStringArray('root', root, False)
+    name = sanitize.validString('name', name, False)
+    fuzzySearchOnName = sanitize.validBool(
+        'fuzzySearchOnName', fuzzySearchOnName, True)
+    userId = sanitize.validUuid('userId', userId, False)
+    pageStart = sanitize.validUuid('pageStart', pageStart, False)
+
+    if root != None and token == None and (len(root) > 1 or root[0] != 'public'):
+        raise ValueError(
+            "When no token is given the root can only be ['public'']")
+
+    body = {
+        'type': ['file'],
+        'root': root,
+        'name': name,
+        'fuzzySearchOnName': fuzzySearchOnName,
+        'userId': userId,
+        'pagestart': pageStart
+    }
+    
+    def f(body):
+        return (apiManager.get('/path', body, token))
+
+    r = recurse(f, body, listAll)
+    return r
+
+
+
 def get(pathId, token=None):
     pathId = sanitize.validUuid('pathId', pathId, True)
     token = sanitize.validString('token', token, False)
@@ -132,6 +165,8 @@ def get(pathId, token=None):
     r = convertPath(r)
     return r
 
+
+####depricated
 def listPath(pathId, pathType, pageStart=None, listAll = True, token=None):
     pathId = sanitize.validUuid('pathId', pathId, True)
     token = sanitize.validString('token', token, False)
@@ -170,7 +205,7 @@ def editMetadata(pathId, token, description=None, attribution=None, licenseStrin
         'license': licenseString
     }, token)
 
-
+#####depricated
 def add( pathType, name, token, parentId = None, publicAccess =None, metadata=None):
     pathType = sanitize.validString('pathType', pathType, True)
     name = sanitize.validString('name', name, True)
@@ -230,10 +265,10 @@ def delete(pathId, token, recursive = False):
     if recursive:
         info = get(pathId, token)
         if info['type'] == 'folder':
-            folders = listPath(pathId, pathType='folder', token=token)['result']
+            folders = listFolder(pathId = pathId, includeTrashed=True, pathTypes=['folder'], token=token)['result']
             for f in folders:
                 delete(f['id'], token, True)
-            maps = listPath(pathId, pathType='layer', token=token)['result']
+            maps = listFolder(pathId=pathId, pathTypes=['raster','vector','file'], includeTrashed=True, token=token)['result']
             for m in maps:
                 delete(m['id'], token, True)
         apiManager.delete(f'/path/{pathId}', None, token)            
